@@ -2,7 +2,7 @@
 /*jslint browser: true */
 /*global $, jQuery, OpenLayers, window, map, updateLayer, fillSidebar,
 setUpScreen, nothingFoundPopup, reloadGraphs, reloadMapActions,
-setUpAnimationSlider, setUpLegendTooltips */
+setUpTransparencySlider, setUpAnimationSlider, setUpLegendTooltips */
 
 
 /*
@@ -64,16 +64,18 @@ But those aren't used anymore.
 */
 
 function show_popup(data, map) {
-    if (data.html !== "" && data.html !== undefined) {
-        var overlay;
-        $('#graph-popup-content').html(data.html);
-        overlay = $('#graph-popup').overlay();
-        overlay.load();
-        reloadGraphs();
-        $(".add-snippet").snippetInteraction();
-    }
-    else {
-        nothingFoundPopup();
+    if (data !== null) {
+        if (data.html !== "" && data.html !== undefined) {
+            var overlay;
+            $('#graph-popup-content').html(data.html);
+            overlay = $('#graph-popup').overlay();
+            overlay.load();
+            reloadGraphs();
+            $(".add-snippet").snippetInteraction();
+        }
+        else {
+            nothingFoundPopup();
+        }
     }
 }
 
@@ -244,6 +246,7 @@ jQuery.fn.updateWorkspace = function () {
                 $(".map-actions").html(
                     $('.map-actions', $holder).html());
                 setUpAnimationSlider();
+                setUpTransparencySlider();
                 setUpLegendTooltips();
             }
         );
