@@ -297,7 +297,9 @@ class WorkspaceCollageSnippetGroup(models.Model):
                     # Base statistics for each period.
                     statistics_row = snippet_adapter.value_aggregate(
                         snippet.identifier,
-                        {'min': None, 'max': None, 'avg': None,
+                        {'min': None,
+                         'max': None,
+                         'avg': None,
                          'count_lt': self.boundary_value,
                          'count_gte': self.boundary_value,
                          'percentile': self.percentile_value},
@@ -312,6 +314,31 @@ class WorkspaceCollageSnippetGroup(models.Model):
                             self.aggregation_period)
                         statistics.append(statistics_row)
 
+        if len(statistics) > 1:
+            # Also show a 'totals' column.
+            averages = [row['avg'] for row in statistics if row['avg']]
+            totals = {
+                'min': min([row['min'] for row in statistics]),
+                'max': max([row['max'] for row in statistics]),
+                'avg': float(sum(averages) / len(averages)),
+                'name': 'Totaal',
+                }
+            if statistics[0]['count_lt'] is not None:
+                totals['count_lt'] = sum(
+                    [row['count_lt'] for row in statistics
+                     if row['count_lt']])
+            else:
+                totals['count_lt'] = None
+            if statistics[0]['count_gte'] is not None:
+                totals['count_gte'] = sum(
+                    [row['count_gte'] for row in statistics
+                     if row['count_gte']])
+            else:
+                totals['count_gte'] = None
+            # We cannot calculate a meaningful total percentile here.
+            totals['percentile'] = None
+            statistics.append(totals)
+
         return statistics
 
     def values_table(self, start_date, end_date):
@@ -595,4 +622,3 @@ class Legend(models.Model):
                     self.too_high_color = makecolor(v)
                 except ValueError:
                     logger.warn('Could not parse too_high_color (%s)' % v)
-
